import $ from 'jquery';

/**
 * A script to make an entire element clickable.
 * @param options
 */
$.fn.fullClickableElement = function (options) {
	// Default settings.
	let $scope = $(this),
		settings = $.extend({}, {
		selector: '.card'
	}, options);

	// Detect clickable elements.
	$scope.find(settings.selector).each(function () {
		let $anchors = $(this).find('a[href]'),
			url_properties = getUrlProperties($anchors, $(this));

		// Check if any elements are in the selector and check if valid url properties are available.
		if ($anchors.length > 0 && Object.keys(url_properties).length > 0) {
			// Set a class name on the full clickable element.
			$(this).addClass('full-clickable-element');

			// Get url properties.
			let url = url_properties.url,
				target = url_properties.target;

			// Handle click on the full clickable element.
			$(this).on('click', function () {
				// Handle both external and internal urls.
				target === 'blank' ? window.open(url) : window.location.href = url;
			});
		}
	});

	/**
	 * Detect a unique url within the selector.
	 * @param anchors
	 * @returns {*}
	 */
	function getUrlProperties(anchors) {
		let hrefs = [],
			target = $(anchors[0]).attr('target') ? 'blank' : 'self';

		// Loop through all anchors.
		anchors.each(function (i, anchor) {
			var href = $(anchor).attr('href');

			// Push all anchors with a valid value.
			href !== undefined ? hrefs.push(href) : null;
		});

		if (hrefs.length < 1) {
			// Return nothing when there are no valid anchors.
			return {};
		} else if (hrefs.length === 1) {
			// Just return the properties of the first anchor when there's just one anchor.
			return {
				'url': hrefs[0],
				'target': target
			};
		}

		// Determine anchor properties when there are multiple anchors.
		for (let i = 1; i < hrefs.length; i++) {
			if (hrefs[i] !== hrefs[0]) {
				// Return nothing when there are different links in the selector.
				return {};
			} else {
				// Return the properties of the first anchor when all anchors are the same.
				return {
					'url': hrefs[0],
					'target': target
				};
			}
		}
	}
};
